==> ffun-0.2.0.tar.gz: ffun-0.2.0/ffun/user_settings/types.py <==
# TODO: rename this module, because mypy does not support name `types`
# TODO: refactor to use pydantic instead of custom types

import enum
from typing import Any

from cryptography.fernet import Fernet

from .settings import settings


class TypeId(str, enum.Enum):
    integer = "integer"
    string = "string"
    boolean = "boolean"
    secret = "secret"


class Type:
    id: TypeId = NotImplemented

    def serialize(self, value: Any) -> str:
        raise NotImplementedError('You must implement "serialize" method in child class')

    def deserialize(self, data: str) -> Any:
        raise NotImplementedError('You must implement "deserialize" method in child class')

    def normalize(self, value: Any) -> Any:
        raise NotImplementedError('You must implement "normalize" method in child class')


class Integer(Type):
    id = TypeId.integer

    def serialize(self, value: int) -> str:
        return str(value)

    def deserialize(self, data: str) -> int:
        return int(data)

    def normalize(self, value: Any) -> int:
        if value == "":
            return 0

        return int(value)


class String(Type):
    id = TypeId.string

    def serialize(self, value: str) -> str:
        return value

    def deserialize(self, data: str) -> str:
        return data

    def normalize(self, value: Any) -> str:
        return str(value)


class Boolean(Type):
    id = TypeId.boolean

    def serialize(self, value: bool) -> str:
        return "true" if value else "false"

    def deserialize(self, data: str) -> bool:
        return data == "true"

    def normalize(self, value: Any) -> bool:
        return value in (True, "true", "True")


class Secret(Type):
    id = TypeId.secret

    def __init__(self, **kwargs: Any) -> None:
        super().__init__(**kwargs)
        self.fernet = Fernet(settings.secret_key)

    def serialize(self, value: str) -> str:
        return self.fernet.encrypt(value.encode()).decode()

    def deserialize(self, data: str) -> str:
        return self.fernet.decrypt(data.encode()).decode()

    def normalize(self, value: Any) -> str:
        return str(value)

==> ffun-1.3.0.tar.gz: ffun-1.3.0/ffun/user_settings/types.py <==
# TODO: rename this module, because mypy does not support name `types`
# TODO: refactor to use pydantic instead of custom types

import enum
from typing import Any

from cryptography.fernet import Fernet

from ffun.user_settings import errors
from ffun.user_settings.settings import settings


class TypeId(str, enum.Enum):
    integer = "integer"
    string = "string"
    boolean = "boolean"
    secret = "secret"  # noqa: S105


class Type:
    id: TypeId = NotImplemented

    def serialize(self, value: Any) -> str:
        raise NotImplementedError('You must implement "serialize" method in child class')

    def deserialize(self, data: str) -> Any:
        raise NotImplementedError('You must implement "deserialize" method in child class')

    def normalize(self, value: Any) -> Any:
        raise NotImplementedError('You must implement "normalize" method in child class')


class Integer(Type):
    id = TypeId.integer

    def serialize(self, value: int) -> str:
        if not isinstance(value, int):
            raise errors.WrongValueType(value=value)

        return str(value)

    def deserialize(self, data: str) -> int:
        return int(data)

    def normalize(self, value: Any) -> int:
        if value == "":
            return 0

        return int(value)


class String(Type):
    id = TypeId.string

    def serialize(self, value: str) -> str:
        return value

    def deserialize(self, data: str) -> str:
        return data

    def normalize(self, value: Any) -> str:
        return str(value)


class Boolean(Type):
    id = TypeId.boolean

    def serialize(self, value: bool) -> str:
        return "true" if value else "false"

    def deserialize(self, data: str) -> bool:
        return data == "true"

    def normalize(self, value: Any) -> bool:
        return value in (True, "true", "True")


class Secret(Type):
    id = TypeId.secret

    def __init__(self, **kwargs: Any) -> None:
        super().__init__(**kwargs)
        self.fernet = Fernet(settings.secret_key)

    def serialize(self, value: str) -> str:
        return self.fernet.encrypt(value.encode()).decode()

    def deserialize(self, data: str) -> str:
        return self.fernet.decrypt(data.encode()).decode()

    def normalize(self, value: Any) -> str:
        return str(value)
